@@ -36,6 +36,7 @@
 
 #include "dealer.h"
 #include "dealerinfo.h"
+#include "kpat_debug.h"
 #include "mainwindow.h"
 #include "version.h"
 #include "patsolve/solverinterface.h"
@@ -45,8 +46,6 @@
 
 #include <KAboutData>
 #include <KCrash>
-
-#include <QDebug>
 #include <KLocalizedString>
 #include <KDBusService>
 
@@ -76,7 +75,7 @@ static DealerScene *getDealer( int wanted_game )
 
             if ( !d->solver() )
             {
-                qCritical() << "There is no solver for" << di->nameForId( wanted_game );;
+                qCCritical(KPAT_LOG) << "There is no solver for" << di->nameForId( wanted_game );;
                 return nullptr;
             }
 
@@ -166,6 +165,9 @@ int main( int argc, char **argv )
     aboutData.addAuthor( i18n("Parker Coates"),
                          i18n("Cleanup and polish"),
                          QStringLiteral("coates@kde.org") );
+    aboutData.addAuthor( i18n("Shlomi Fish"),
+                         i18n("Integration with Freecell Solver and further work"),
+                         QStringLiteral("shlomif@cpan.org") );
 
     // Create a KLocale earlier than normal so that we can use i18n to translate
     // the names of the game types in the help text.
